//********************************************************************
// Author: W. Savitch (modified by L. Kosseim)
//
//  This program demonstrates how to format output with DecimalFormat
//********************************************************************

import java.text.DecimalFormat; // we need to import this class

public class DecimalFormatDemo
{
    public static void main(String[] args)
    {
        // let's create some patterns for the format
        DecimalFormat pattern00dot000 = new DecimalFormat("00.000");
        DecimalFormat pattern0dot00 = new DecimalFormat("0.00");

        // let's see how the patterns can be used
        double d = 12.3456789;
        System.out.println("Pattern 00.000");
        System.out.println(pattern00dot000.format(d));
        System.out.println("Pattern 0.00");
        System.out.println(pattern0dot00.format(d));

        // let's see how we can format money with DecimalFormat
        double money = 19.8;
        System.out.println("Pattern 0.00");
        System.out.println("$" + pattern0dot00.format(money));
        
        DecimalFormat percent = new DecimalFormat("0.00%");

        System.out.println("Pattern 0.00%");
        System.out.println(percent.format(0.308));

        // let's format in exponential notation
        DecimalFormat eNotation1 =
           new DecimalFormat("#0.###E0");//1 or 2 digits before point
        DecimalFormat eNotation2 =
           new DecimalFormat("00.###E0");//2 digits before point

        System.out.println("Pattern #0.###E0");
        System.out.println(eNotation1.format(123.456));
        System.out.println("Pattern 00.###E0");
        System.out.println(eNotation2.format(123.456));

        double smallNumber = 0.0000123456;
        System.out.println("Pattern #0.###E0");
        System.out.println(eNotation1.format(smallNumber));
        System.out.println("Pattern 00.###E0");
        System.out.println(eNotation2.format(smallNumber));
    }
}
